@@ -31,42 +31,26 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <libtasn1.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <getopt.h>
 
-#ifdef HAVE_GETOPT_H
-  #include <getopt.h>
-#endif
+#include <libtasn1.h>
 
-char version_man[] = "asn1Coding (GNU libtasn1) " VERSION "\n"
-  "Written by Fabio Fiorina."
-  "\n"
-  "Copyright (C) 2002, 2006 Free Software Foundation, Inc.\n";
+#include <progname.h>
+#include <version-etc.h>
 
-char help_man[] =
-  "Usage: asn1Coding [options] <file1> <file2>\n"
+static const char help_man[] =
+  "Usage: asn1Coding [OPTION] DEFINITIONS ASSIGNMENTS\n"
+  "asn1Coding generates a DER encoding of ASN.1 DEFINITIONS file\n"
+  "and ASSIGNMENTS file with value assignments.\n"
   "\n"
-  "asn1Coding generates a DER encoding from FILE1\n"
-  "with ASN1 definitions and FILE2 with assignments.\n"
+  "Mandatory arguments to long options are mandatory for short options too.\n"
+  "  -c, --check           checks the syntax only\n"
+  "  -o, --output FILE     output file\n"
+  "  -h, --help            display this help and exit\n"
+  "  -v, --version         output version information and exit.\n"
   "\n"
-#ifdef HAVE_GETOPT_LONG
-  "Operation modes:\n"
-  "  -h, --help    shows this message and exit.\n"
-  "  -v, --version shows version information and exit.\n"
-  "  -c, --check   checks the syntax only.\n"
-  "\n"
-  "Output:\n"
-  "  -o <file>, --output <file>  output file.\n"
-#else
-  "Operation modes:\n"
-  "  -h    shows this message and exit.\n"
-  "  -v    shows version information and exit.\n"
-  "  -c    checks the syntax only.\n"
-  "\n"
-  "Output:\n"
-  "  -o <file>  output file.\n"
-#endif
   "Report bugs to <" PACKAGE_BUGREPORT ">.";
 
 #define ASSIGNMENT_SUCCESS 1
@@ -127,8 +111,6 @@ void createFileName(char *inputFileName, char **outputFileName)
 int
 main(int argc,char *argv[])
 {
-
-#ifdef HAVE_GETOPT_LONG
   static struct option long_options[] =
   {
     {"help",    no_argument,       0, 'h'},
@@ -138,8 +120,6 @@ main(int argc,char *argv[])
     {0, 0, 0, 0}
   };
   int option_index=0;
-#endif
-
  int option_result;
  char *outputFileName=NULL;
  char *inputFileAsnName=NULL;
@@ -157,17 +137,13 @@ main(int argc,char *argv[])
  int  der_len;
  int  k;
 
- opterr=0; /* disable error messages from getopt */
+ set_program_name (argv[0]);
 
- printf("\n");
+ opterr=0; /* disable error messages from getopt */
 
  while(1){
 
-#ifdef HAVE_GETOPT_LONG
    option_result=getopt_long(argc,argv,"hvco:",long_options,&option_index);
-#else
-   option_result=getopt(argc,argv,"hvco:");
-#endif
 
    if(option_result == -1) break;
 
@@ -179,8 +155,8 @@ main(int argc,char *argv[])
      exit(0);
      break;
    case 'v':  /* VERSION */
-     printf("%s\n",version_man);
-
+     version_etc (stdout, program_name, PACKAGE, VERSION,
+		  "Fabio Fiorina", NULL);
      if(outputFileName) free(outputFileName);
      exit(0);
      break;
@@ -341,8 +317,3 @@ main(int argc,char *argv[])
 
  exit(0);
 }
-
-
-
-
-
