@@ -31,39 +31,24 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <libtasn1.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <getopt.h>
 
-#ifdef HAVE_GETOPT_H
-  #include <getopt.h>
-#endif
+#include <libtasn1.h>
 
-char version_man[] = "asn1Decoding (GNU libtasn1) " VERSION "\n"
-  "Written by Fabio Fiorina."
-  "\n"
-  "Copyright (C) 2002, 2006 Free Software Foundation, Inc.\n";
+#include <progname.h>
+#include <version-etc.h>
 
-char help_man[] =
-  "asn1Decoding generates an ASN1 type from FILE1\n"
-  "with ASN1 definitions and FILE2 with a DER encoding.\n"
+static const char help_man[] =
+  "Usage: asn1Decoding [OPTION] DEFINITIONS ENCODED ASN1TYPE\n"
+  "asn1Decoding decodes DER data in ENCODED file, for the ASN1TYPE element\n"
+  "described in ASN.1 DEFINITIONS file, and print decoded structures.\n"
   "\n"
-  "Usage: asn1Decoding [options] <file1> <file2> <type>\n"
-  " <file1> file with ASN1 definitions.\n"
-  " <file2> file with a DER coding.\n"
-  " <type>  ASN1 type name\n"
+  "  -c, --check           checks the syntax only\n"
+  "  -h, --help            display this help and exit\n"
+  "  -v, --version         output version information and exit.\n"
   "\n"
-#ifdef HAVE_GETOPT_LONG
-  "Operation modes:\n"
-  "  -h, --help    shows this message and exit.\n"
-  "  -v, --version shows version information and exit.\n"
-  "  -c, --check   checks the syntax only.\n"
-#else
-  "Operation modes:\n"
-  "  -h    shows this message and exit.\n"
-  "  -v    shows version information and exit.\n"
-  "  -c    checks the syntax only.\n"
-#endif
   "Report bugs to <" PACKAGE_BUGREPORT ">.";
 
 /********************************************************/
@@ -73,8 +58,6 @@ char help_man[] =
 int
 main(int argc,char *argv[])
 {
-
-#ifdef HAVE_GETOPT_LONG
   static struct option long_options[] =
   {
     {"help",    no_argument,       0, 'h'},
@@ -83,8 +66,6 @@ main(int argc,char *argv[])
     {0, 0, 0, 0}
   };
  int option_index = 0;
-#endif
-
  int option_result;
  char *inputFileAsnName=NULL;
  char *inputFileDerName=NULL; 
@@ -99,17 +80,13 @@ main(int argc,char *argv[])
  int  der_len=0;
  /* FILE *outputFile; */ 
 
- opterr=0; /* disable error messages from getopt */
+ set_program_name (argv[0]);
 
- printf("\n");
+ opterr=0; /* disable error messages from getopt */
 
  while(1){
 
-#ifdef HAVE_GETOPT_LONG
    option_result=getopt_long(argc,argv,"hvc",long_options,&option_index);
-#else
-   option_result=getopt(argc,argv,"hvc");
-#endif
 
    if(option_result == -1) break;
 
@@ -119,7 +96,8 @@ main(int argc,char *argv[])
      exit(0);
      break;
    case 'v':  /* VERSION */
-     printf("%s\n",version_man);
+     version_etc (stdout, program_name, PACKAGE, VERSION,
+		  "Fabio Fiorina", NULL);
      exit(0);
      break;
    case 'c':  /* CHECK SYNTAX */
@@ -280,10 +258,3 @@ main(int argc,char *argv[])
 
  exit(0);
 }
-
-
-
-
-
-
-
